@@ -109,7 +109,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -125,28 +125,28 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_mediastore
-import aws_cdk.aws_s3
-import constructs
+import aws_cdk.aws_cloudfront as _aws_cdk_aws_cloudfront_ceddda9d
+import aws_cdk.aws_mediastore as _aws_cdk_aws_mediastore_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class CloudFrontToMediaStore(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-cloudfront-mediastore.CloudFrontToMediaStore",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_media_store_container_obj: typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        media_store_container_props: typing.Optional[typing.Union[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -163,19 +163,7 @@ class CloudFrontToMediaStore(
         :summary: Constructs a new instance of CloudFrontToMediaStore class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7437ce689f4f0c8bcce19a9f24f6d85ab2e5133c551b0fc77d0d61eeb969839b)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontToMediaStoreProps(
@@ -193,35 +181,41 @@ class CloudFrontToMediaStore(
     @jsii.member(jsii_name="cloudFrontOriginRequestPolicy")
     def cloud_front_origin_request_policy(
         self,
-    ) -> aws_cdk.aws_cloudfront.OriginRequestPolicy:
-        return typing.cast(aws_cdk.aws_cloudfront.OriginRequestPolicy, jsii.get(self, "cloudFrontOriginRequestPolicy"))
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.OriginRequestPolicy:
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.OriginRequestPolicy, jsii.get(self, "cloudFrontOriginRequestPolicy"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
+    def cloud_front_web_distribution(
+        self,
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, jsii.get(self, "cloudFrontWebDistribution"))
 
     @builtins.property
     @jsii.member(jsii_name="mediaStoreContainer")
-    def media_store_container(self) -> aws_cdk.aws_mediastore.CfnContainer:
-        return typing.cast(aws_cdk.aws_mediastore.CfnContainer, jsii.get(self, "mediaStoreContainer"))
+    def media_store_container(self) -> _aws_cdk_aws_mediastore_ceddda9d.CfnContainer:
+        return typing.cast(_aws_cdk_aws_mediastore_ceddda9d.CfnContainer, jsii.get(self, "mediaStoreContainer"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontFunction")
-    def cloud_front_function(self) -> typing.Optional[aws_cdk.aws_cloudfront.Function]:
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.Function], jsii.get(self, "cloudFrontFunction"))
+    def cloud_front_function(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.Function], jsii.get(self, "cloudFrontFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
-    def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
+    def cloud_front_logging_bucket(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.Bucket], jsii.get(self, "cloudFrontLoggingBucket"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontOriginAccessIdentity")
     def cloud_front_origin_access_identity(
         self,
-    ) -> typing.Optional[aws_cdk.aws_cloudfront.OriginAccessIdentity]:
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.OriginAccessIdentity], jsii.get(self, "cloudFrontOriginAccessIdentity"))
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.OriginAccessIdentity]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.OriginAccessIdentity], jsii.get(self, "cloudFrontOriginAccessIdentity"))
 
 
 @jsii.data_type(
@@ -241,11 +235,11 @@ class CloudFrontToMediaStoreProps:
         self,
         *,
         cloud_front_distribution_props: typing.Any = None,
-        cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-        existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
+        cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_media_store_container_obj: typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer] = None,
         insert_http_security_headers: typing.Optional[builtins.bool] = None,
-        media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
-        response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
+        media_store_container_props: typing.Optional[typing.Union[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param cloud_front_distribution_props: Optional user provided props to override the default props for the CloudFront. Default: - Default props are used
@@ -258,30 +252,20 @@ class CloudFrontToMediaStoreProps:
         :summary: The properties for the CloudFrontToMediaStore Construct
         '''
         if isinstance(cloud_front_logging_bucket_props, dict):
-            cloud_front_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**cloud_front_logging_bucket_props)
+            cloud_front_logging_bucket_props = _aws_cdk_aws_s3_ceddda9d.BucketProps(**cloud_front_logging_bucket_props)
         if isinstance(media_store_container_props, dict):
-            media_store_container_props = aws_cdk.aws_mediastore.CfnContainerProps(**media_store_container_props)
+            media_store_container_props = _aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps(**media_store_container_props)
         if isinstance(response_headers_policy_props, dict):
-            response_headers_policy_props = aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps(**response_headers_policy_props)
+            response_headers_policy_props = _aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps(**response_headers_policy_props)
         if __debug__:
-            def stub(
-                *,
-                cloud_front_distribution_props: typing.Any = None,
-                cloud_front_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_media_store_container_obj: typing.Optional[aws_cdk.aws_mediastore.CfnContainer] = None,
-                insert_http_security_headers: typing.Optional[builtins.bool] = None,
-                media_store_container_props: typing.Optional[typing.Union[aws_cdk.aws_mediastore.CfnContainerProps, typing.Dict[str, typing.Any]]] = None,
-                response_headers_policy_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e4eb071d044bbbdbcd70b34164c41ffbfadd12ac9e1276cbe91fef9540ef6bd1)
             check_type(argname="argument cloud_front_distribution_props", value=cloud_front_distribution_props, expected_type=type_hints["cloud_front_distribution_props"])
             check_type(argname="argument cloud_front_logging_bucket_props", value=cloud_front_logging_bucket_props, expected_type=type_hints["cloud_front_logging_bucket_props"])
             check_type(argname="argument existing_media_store_container_obj", value=existing_media_store_container_obj, expected_type=type_hints["existing_media_store_container_obj"])
             check_type(argname="argument insert_http_security_headers", value=insert_http_security_headers, expected_type=type_hints["insert_http_security_headers"])
             check_type(argname="argument media_store_container_props", value=media_store_container_props, expected_type=type_hints["media_store_container_props"])
             check_type(argname="argument response_headers_policy_props", value=response_headers_policy_props, expected_type=type_hints["response_headers_policy_props"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if cloud_front_distribution_props is not None:
             self._values["cloud_front_distribution_props"] = cloud_front_distribution_props
         if cloud_front_logging_bucket_props is not None:
@@ -307,24 +291,24 @@ class CloudFrontToMediaStoreProps:
     @builtins.property
     def cloud_front_logging_bucket_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
         '''Optional user provided props to override the default props for the CloudFront Logging Bucket.
 
         :default: - Default props are used
         '''
         result = self._values.get("cloud_front_logging_bucket_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps], result)
 
     @builtins.property
     def existing_media_store_container_obj(
         self,
-    ) -> typing.Optional[aws_cdk.aws_mediastore.CfnContainer]:
+    ) -> typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer]:
         '''Existing instance of mediastore.CfnContainer obejct.
 
         :default: - None
         '''
         result = self._values.get("existing_media_store_container_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_mediastore.CfnContainer], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer], result)
 
     @builtins.property
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
@@ -341,18 +325,18 @@ class CloudFrontToMediaStoreProps:
     @builtins.property
     def media_store_container_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps]:
+    ) -> typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps]:
         '''Optional user provided props to override the default props for the MediaStore.
 
         :default: - Default props are used
         '''
         result = self._values.get("media_store_container_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_mediastore.CfnContainerProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps], result)
 
     @builtins.property
     def response_headers_policy_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps]:
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps]:
         '''Optional user provided configuration that cloudfront applies to all http responses.
 
         Can be used to pass a custom ResponseSecurityHeadersBehavior, ResponseCustomHeadersBehavior or
@@ -365,7 +349,7 @@ class CloudFrontToMediaStoreProps:
         :default: - undefined
         '''
         result = self._values.get("response_headers_policy_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.ResponseHeadersPolicyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -385,3 +369,29 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7437ce689f4f0c8bcce19a9f24f6d85ab2e5133c551b0fc77d0d61eeb969839b(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_media_store_container_obj: typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    media_store_container_props: typing.Optional[typing.Union[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e4eb071d044bbbdbcd70b34164c41ffbfadd12ac9e1276cbe91fef9540ef6bd1(
+    *,
+    cloud_front_distribution_props: typing.Any = None,
+    cloud_front_logging_bucket_props: typing.Optional[typing.Union[_aws_cdk_aws_s3_ceddda9d.BucketProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_media_store_container_obj: typing.Optional[_aws_cdk_aws_mediastore_ceddda9d.CfnContainer] = None,
+    insert_http_security_headers: typing.Optional[builtins.bool] = None,
+    media_store_container_props: typing.Optional[typing.Union[_aws_cdk_aws_mediastore_ceddda9d.CfnContainerProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    response_headers_policy_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.ResponseHeadersPolicyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
